@@ -345,10 +345,9 @@ class Composition(collections.Mapping, collections.Hashable, MSONable):
         return self._elmap.keys()
 
     def __str__(self):
-        return " ".join(["{}{}".format(k,
-                                       formula_double_format(v,
-                                                             ignore_ones=False))
-                         for k, v in self.to_dict.items()])
+        return " ".join([
+            "{}{}".format(k, formula_double_format(v, ignore_ones=False))
+            for k, v in self.to_dict.items()])
 
     @property
     def num_atoms(self):
@@ -478,7 +477,7 @@ class Composition(collections.Mapping, collections.Hashable, MSONable):
     def get_el_amt_dict(self):
         """
         Returns:
-            dict with species symbol and (unreduced) amount e.g.,
+            Dict with element symbol and (unreduced) amount e.g.,
             {"Fe": 4.0, "O":6.0} or {"Fe3+": 4.0, "O2-":6.0}
         """
         d = collections.defaultdict(float)
@@ -502,7 +501,7 @@ class Composition(collections.Mapping, collections.Hashable, MSONable):
     def to_reduced_dict(self):
         """
         Returns:
-            dict with element symbol and reduced amount e.g.,
+            Dict with element symbol and reduced amount e.g.,
             {"Fe": 2.0, "O":3.0}
         """
         c = Composition(self.reduced_formula)
@@ -511,10 +510,10 @@ class Composition(collections.Mapping, collections.Hashable, MSONable):
     @property
     def to_data_dict(self):
         """
-        Returns a dict with many composition-related properties.
-
         Returns:
-            A dict with many keys and values relating to Composition/Formula
+            A dict with many keys and values relating to Composition/Formula,
+            including reduced_cell_composition, unit_cell_composition,
+            reduced_cell_formula, elements and nelements.
         """
         return {"reduced_cell_composition": self.to_reduced_dict,
                 "unit_cell_composition": self.to_dict,
