@@ -97,6 +97,30 @@ class SiteCollection(collections.Sequence, collections.Hashable):
         """
         return [site.species_and_occu for site in self]
 
+    @property
+    def types_of_specie(self):
+        """
+        List of types of specie. Only works for ordered structures.
+        Disordered structures will raise an AttributeError.
+        """
+        types = []  # Cannot use sets since we want a deterministic algorithm.
+        for site in self:
+            if site.specie not in types:
+                types.append(site.specie)
+        return types
+
+    def group_by_types(self):
+        """Iterate over species grouped by type"""
+        for t in self.types_of_specie:
+            for site in self:
+                if site.specie == t:
+                    yield site
+
+    @property
+    def atomic_numbers(self):
+        """List of atomic numbers."""
+        return [site.specie.number for site in self]
+
     @property
     def site_properties(self):
         """
@@ -314,7 +338,6 @@ class Structure(SiteCollection, MSONable):
             raise StructureError(("Structure contains sites that are ",
                                   "less than 0.01 Angstrom apart!"))
 
-
     @staticmethod
     def from_sites(sites):
         """
@@ -352,6 +375,21 @@ class Structure(SiteCollection, MSONable):
         """
         return self._lattice
 
+    def lattice_vectors(self, space="r"):
+        """
+        Returns the vectors of the unit cell in Angstrom.
+
+        Args:
+            space:
+                "r" for real space vectors, "g" for reciprocal space basis
+                vectors.
+        """
+        if space.lower() == "r":
+            return self.lattice.matrix
+        if space.lower() == "g":
+            return self.lattice.reciprocal_lattice.matrix
+        raise ValueError("Wrong value for space: %s " % space)
+
     @property
     def density(self):
         """
@@ -919,7 +957,6 @@ class Molecule(SiteCollection, MSONable):
                 length as the atomic species and fractional_coords.
                 Defaults to None for no properties.
         """
-        #TODO: support charged molecules.
         if len(species) != len(coords):
             raise StructureError(("The list of atomic species must be of the",
                                   " same length as the list of fractional ",
@@ -1102,7 +1139,7 @@ class Molecule(SiteCollection, MSONable):
     def __repr__(self):
         outs = ["Molecule Summary"]
         for s in self:
-            outs.append(repr(s))
+            outs.append(s.__repr__())
         return "\n".join(outs)
 
     def __str__(self):
@@ -1278,14 +1315,4 @@ class StructureError(Exception):
     Exception class for Structure.
     Raised when the structure has problems, e.g., atoms that are too close.
     """
-
-    def __init__(self, msg):
-        """
-        Args:
-            msg:
-                The error message.
-        """
-        self.msg = msg
-
-    def __str__(self):
-        return self.msg
+    pass
