@@ -19,6 +19,12 @@ from pymatgen.electronic_structure.core import Spin, Orbital
 from pymatgen.core.structure import Structure
 from pymatgen.util.coord_utils import get_linear_interpolated_value
 from pymatgen.serializers.json_coders import MSONable
+from pymatgen.util.decorators import requires
+
+try:
+    import scipy
+except ImportError:
+    scipy = None
 
 
 class Dos(MSONable):
@@ -77,6 +83,8 @@ class Dos(MSONable):
             result = self.densities[spin]
         return result
 
+    @requires(scipy is not None, "get_smeared_densities requires scipy to be "
+                                 "installed.")
     def get_smeared_densities(self, sigma):
         """
         Returns the Dict representation of the densities, {Spin: densities},
@@ -304,10 +312,9 @@ class CompleteDos(Dos):
                     The pdoss are supplied as an {Site:{Orbital:{
                     Spin:Densities}}}
             """
-        self.efermi = total_dos.efermi
-        self.energies = np.array(total_dos.energies)
-        self.densities = {k: np.array(d)
-                          for k, d in total_dos.densities.items()}
+        Dos.__init__(self, total_dos.efermi, energies=total_dos.energies,
+                     densities={k: np.array(d)
+                                for k, d in total_dos.densities.items()})
         self.pdos = pdoss
         self.structure = structure
 
