@@ -599,8 +599,8 @@ class Incar(dict):
         list_keys = ("LDAUU", "LDAUL", "LDAUJ", "LDAUTYPE", "MAGMOM")
         bool_keys = ("LDAU", "LWAVE", "LSCALU", "LCHARG", "LPLANE", "LHFCALC")
         float_keys = ("EDIFF", "SIGMA", "TIME", "ENCUTFOCK", "HFSCREEN")
-        int_keys = ("NSW", "NELMIN", "ISIF", "IBRION", "ISPIN", "ICHARG",
-                    "NELM", "ISMEAR", "NPAR", "LDAUPRINT", "LMAXMIX",
+        int_keys = ("NSW", "NBANDS", "NELMIN", "ISIF", "IBRION", "ISPIN",
+                    "ICHARG", "NELM", "ISMEAR", "NPAR", "LDAUPRINT", "LMAXMIX",
                     "ENCUT", "NSIM", "NKRED", "NUPDOWN", "ISPIND")
 
         def smart_int_or_float(numstr):
@@ -725,13 +725,15 @@ class Kpoints(MSONable):
             kpts_shift:
                 Shift for Kpoints.
             kpts_weights:
-                Optional weights for kpoints.  For explicit kpoints.
+                Optional weights for kpoints.  Weights should be integers. For
+                explicit kpoints.
             coord_type:
                 In line-mode, this variable specifies whether the Kpoints were
                 given in Cartesian or Reciprocal coordinates.
             labels:
                 In line-mode, this should provide a list of labels for each
-                kpt. It is optional in explicit kpoint mode as comments for k-points.
+                kpt. It is optional in explicit kpoint mode as comments for
+                k-points.
             tet_number:
                 For explicit kpoints, specifies the number of tetrahedrons for
                 the tetrahedron method.
@@ -870,10 +872,12 @@ class Kpoints(MSONable):
                         and abs(lengths[right_angles[0]] -
                                 lengths[right_angles[1]]) < hex_length_tol)
 
-        style = Kpoints.supported_modes.Gamma
-        if not is_hexagonal:
-            num_div = [i + i % 2 for i in num_div]
-            style = Kpoints.supported_modes.Monkhorst
+        all_odd = all([i % 2 == 1 for i in num_div])
+
+        style = Kpoints.supported_modes.Monkhorst
+        if all_odd or is_hexagonal:
+            style = Kpoints.supported_modes.Gamma
+
         comment = "pymatgen generated KPOINTS with grid density = " + \
             "{} / atom".format(kppa)
         num_kpts = 0
@@ -1004,9 +1008,10 @@ class Kpoints(MSONable):
                 lines[-1] += " ! " + self.labels[i]
             elif self.num_kpts > 0:
                 if self.labels is not None:
-                    lines[-1] += " %f %s" % (self.kpts_weights[i], self.labels[i])
+                    lines[-1] += " %i %s" % (self.kpts_weights[i],
+                                             self.labels[i])
                 else:
-                    lines[-1] += " %f" % (self.kpts_weights[i])
+                    lines[-1] += " %i" % (self.kpts_weights[i])
 
 
         #Print tetrahedorn parameters if the number of tetrahedrons > 0
@@ -1183,15 +1188,13 @@ class Potcar(list):
         """
         Args:
             symbols:
-                Element symbols for POTCAR
+                Element symbols for POTCAR. This should correspond to the
+                symbols used by VASP. E.g., "Mg", "Fe_pv", etc.
             functional:
                 Functional used.
             sym_potcar_map:
-                Allows a user to specify a specific element symbol to POTCAR
-                symbol mapping. For example, you can have {"Fe":"Fe_pv"} to
-                specify that the Fe_pv psuedopotential should be used for Fe.
-                Default is None, which uses a pre-determined mapping used in
-                the Materials Project.
+                Allows a user to specify a specific element symbol to raw
+                POTCAR mapping.
         """
         super(Potcar, self).__init__()
         self.functional = functional
