@@ -296,7 +296,8 @@ class Vasprun(object):
         """
         return True if self.incar.get("ISPIN", 1) == 2 else False
 
-    def get_band_structure(self, kpoints_filename=None, efermi=None):
+    def get_band_structure(self, kpoints_filename=None, efermi=None,
+                           line_mode=False):
         """
         Returns the band structure as a BandStructure object
 
@@ -308,11 +309,16 @@ class Vasprun(object):
                 determine the appropriate KPOINTS file by substituting the
                 filename of the vasprun.xml with KPOINTS.
                 The latter is the default behavior.
+
             efermi:
                 If you want to specify manually the fermi energy this is where
                 you should do it. By default, the None value means the code
                 will get it from the vasprun.
 
+            line_mode:
+                force the band structure to be considered as a run along
+                symmetry lines
+
         Returns:
             a BandStructure object (or more specifically a
             BandStructureSymmLine object if the run is detected to be a run
@@ -391,7 +397,7 @@ class Vasprun(object):
                 if l is not None:
                     hybrid_band = True
 
-        if kpoint_file.style == "Line_mode" or hybrid_band:
+        if kpoint_file.style == "Line_mode" or hybrid_band or line_mode:
             labels_dict = {}
             if hybrid_band:
                 start_bs_index = 0
@@ -1997,15 +2003,9 @@ class Oszicar(object):
 
 class VaspParserError(Exception):
     """
-    Exception class for Structure.
-    Raised when the structure has problems, e.g., atoms that are too close.
+    Exception class for VASP parsing.
     """
-
-    def __init__(self, msg):
-        self.msg = msg
-
-    def __str__(self):
-        return "VaspParserError : " + self.msg
+    pass
 
 
 def get_band_structure_from_vasp_multiple_branches(dir_name, efermi=None,
