@@ -16,7 +16,7 @@ __date__ = "Mar 13, 2012"
 import math
 
 
-def get_publication_quality_plot(width=8, height=None):
+def get_publication_quality_plot(width=8, height=None, plt=None):
     """
     Provides a publication quality plot, with nice defaults for font sizes etc.
 
@@ -25,21 +25,28 @@ def get_publication_quality_plot(width=8, height=None):
             Width of plot in inches. Defaults to 8in.
         height.
             Height of plot in inches. Defaults to width * golden ratio.
+        plt:
+            If plt is supplied, changes will be made to an existing plot.
+            Otherwise, a new plot will be created.
 
     Returns:
         Matplotlib plot object with properly sized fonts.
     """
-    import matplotlib as mpl
-    import matplotlib.pyplot as plt
-    mpl.rcParams["font.serif"] = "Times New Roman"
-    mpl.rcParams["font.sans-serif"] = "Arial"
     golden_ratio = (math.sqrt(5) - 1.0) / 2.0
     if not height:
         height = int(width * golden_ratio)
-    plt.figure(figsize=(width, height), facecolor="w")
-    plt.ylabel("Y-axis", fontsize=width * 3)
-    plt.xlabel("X-axis", fontsize=width * 3)
-    plt.xticks(fontsize=width * 3)
-    plt.yticks(fontsize=width * 3)
-    plt.title("", fontsize=width * 4)
+    import matplotlib as mpl
+    mpl.rcParams["font.serif"] = "Times New Roman"
+    mpl.rcParams["font.sans-serif"] = "Arial"
+    mpl.rcParams["axes.titlesize"] = width * 4
+    mpl.rcParams["axes.labelsize"] = width * 3
+
+    if plt is None:
+        import matplotlib.pyplot as plt
+        plt.figure(figsize=(width, height), facecolor="w")
+    else:
+        fig = plt.gcf()
+        fig.set_size_inches(width, height)
+    plt.xticks(fontsize=width * 2)
+    plt.yticks(fontsize=width * 2)
     return plt
