@@ -30,7 +30,7 @@ from pymatgen.apps.borg.queen import BorgQueen
 from pymatgen.electronic_structure.plotter import DosPlotter
 from pymatgen.io.vaspio import Poscar
 from pymatgen.io.cifio import CifParser, CifWriter
-from pymatgen.io.vaspio_set import MaterialsProjectVaspInputSet
+from pymatgen.io.vaspio_set import MPVaspInputSet, MITVaspInputSet
 from pymatgen.io.smartio import read_structure, write_structure
 from pymatgen.io.cssrio import Cssr
 from pymatgen.symmetry.finder import SymmetryFinder
@@ -79,10 +79,10 @@ def get_energies(rootdir, reanalyze, verbose, pretty, detailed, sort):
                 e.data["initial_structure"].volume - 1
             delta_vol = "{:.2f}".format(delta_vol * 100)
         all_data.append((e.data["filename"].replace("./", ""),
-                     re.sub("\s+", "", e.composition.formula),
-                     "{:.5f}".format(e.energy),
-                     "{:.5f}".format(e.energy_per_atom),
-                     delta_vol))
+                         re.sub("\s+", "", e.composition.formula),
+                         "{:.5f}".format(e.energy),
+                         "{:.5f}".format(e.energy_per_atom),
+                         delta_vol))
     if len(all_data) > 0:
         headers = ("Directory", "Formula", "Energy", "E/Atom", "% vol chg")
         if pretty:
@@ -176,7 +176,7 @@ def plot_chgint(args):
     plt = get_publication_quality_plot(12, 8)
     for i in atom_ind:
         d = chgcar.get_integrated_diff(i, args.radius, 30)
-        plt.plot(d[:, 0], d[:,1],
+        plt.plot(d[:, 0], d[:, 1],
                  label="Atom {} - {}".format(i, s[i].species_string))
     plt.legend(loc="upper left")
     plt.xlabel("Radius (A)")
@@ -233,7 +233,11 @@ def convert_fmt(args):
             c = Cssr(structure)
             c.write_file(out_filename)
         elif oformat == "VASP":
-            input_set = MaterialsProjectVaspInputSet()
+            input_set = MPVaspInputSet()
+            transmuter = StandardTransmuter.from_structures([structure], [])
+            transmuter.write_vasp_input(input_set, output_dir=out_filename)
+        elif oformat == "MITVASP":
+            input_set = MITVaspInputSet()
             transmuter = StandardTransmuter.from_structures([structure], [])
             transmuter.write_vasp_input(input_set, output_dir=out_filename)
 
@@ -283,7 +287,7 @@ def compare_structures(args):
     from pymatgen.analysis.structure_matcher import StructureMatcher, \
         ElementComparator
     m = StructureMatcher() if args.oxi \
-            else StructureMatcher(comparator=ElementComparator())
+        else StructureMatcher(comparator=ElementComparator())
     for i, grp in enumerate(m.group_structures(structures)):
         print "Group {}: ".format(i)
         for s in grp:
@@ -311,7 +315,7 @@ if __name__ == "__main__":
     analyses, plotting and format conversions. This script works based on
     several sub-commands with their own options. To see the options for the
     sub-commands, type "matgenie.py sub-command -h".""",
-    epilog="""
+                                     epilog="""
     Author: Shyue Ping Ong
     Version: {}
     Last updated: {}""".format(__version__, __date__))
@@ -355,7 +359,7 @@ if __name__ == "__main__":
     parser_plot.add_argument("filename", metavar="filename", type=str, nargs=1,
                              help="vasprun.xml file to plot")
     parser_plot.add_argument("-s", "--site", dest="site", action="store_const",
-                        const=True, help="plot site projected DOS")
+                             const=True, help="plot site projected DOS")
     parser_plot.add_argument("-e", "--element", dest="element", type=str,
                              nargs=1,
                              help="List of elements to plot as comma-separated"
@@ -368,8 +372,8 @@ if __name__ == "__main__":
     parser_plotchg = subparsers.add_parser("plotchgint",
                                            help="Plotting for the charge "
                                                 "integration.")
-    parser_plotchg.add_argument("filename", metavar="filename", type=str, nargs=1,
-                                help="CHGCAR file to plot")
+    parser_plotchg.add_argument("filename", metavar="filename", type=str,
+                                nargs=1, help="CHGCAR file to plot")
     parser_plotchg.add_argument("-i", "--indices", dest="inds", type=str,
                                 nargs=1,
                                 help="Comma-separated list of indices to plot"
@@ -401,6 +405,7 @@ if __name__ == "__main__":
     parser_convert.add_argument("-o", "--output", dest="output_format",
                                 type=str, nargs=1,
                                 choices=["POSCAR", "CIF", "CSSR", "VASP",
+                                         "MITVASP"
                                          "smart"],
                                 default=["smart"],
                                 help="Output file format. By default, smart is"
@@ -408,7 +413,9 @@ if __name__ == "__main__":
                                 "filename. Other formats can be enforced as "
                                 "needed. VASP is a special output form, which "
                                 "outputs a set of VASP input files to a "
-                                "directory.")
+                                "directory. MITVASP uses the MIT input set "
+                                "instead of the default Materials project "
+                                "input set.")
     parser_convert.set_defaults(func=convert_fmt)
 
     parser_symm = subparsers.add_parser("symm", help="Symmetry tools.")
